{% extends "allianceauth/base-bs5.html" %}
{% load i18n %}
{% load humanize %}
{% load static %}

{% block page_title %}
    {% translate "Secret Santa" %}
{% endblock page_title %}

{% block header_nav_brand %}
    {% translate "Secret Santa" %}
{% endblock header_nav_brand %}

{% block content %}
{% endblock content %}
