{% extends "secretsanta/base-bs5.html" %}
{% load i18n %}
{% load humanize %}
{% block content %}
    <div class="row">
        {% for year in year_renders %}{{ year }}{% endfor %}
    </div>
{% endblock content %}
