# Generated by Django 4.2.6 on 2023-10-31 09:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('secretsanta', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='santapair',
            name='delivered',
            field=models.BooleanField(default=False, verbose_name='Delivered'),
        ),
    ]
