# Generated by Django 4.0 on 2023-10-31 14:03

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0012_alter_user_first_name_max_length'),
        ('secretsanta', '0002_alter_santapair_delivered'),
    ]

    operations = [
        migrations.AlterField(
            model_name='application',
            name='user',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='auth.user', verbose_name='User'),
        ),
        migrations.AlterField(
            model_name='secretsantaconfiguration',
            name='delivery_updates',
            field=models.ManyToManyField(help_text='A Santee has marked they have received their gift', to='secretsanta.Webhook', verbose_name='Delivery Updates'),
        ),
    ]
