# Generated by Django 4.2.6 on 2023-11-01 02:28

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('secretsanta', '0003_alter_application_user_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='secretsantaconfiguration',
            options={'default_permissions': (), 'verbose_name': 'Secret Santa Configuration'},
        ),
    ]
