# Generated by Django 4.2.8 on 2023-12-11 10:19

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('secretsanta', '0004_alter_secretsantaconfiguration_options'),
    ]

    operations = [
        migrations.CreateModel(
            name='ActiveSecretSantaFilter',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=500)),
                ('description', models.CharField(max_length=500)),
                ('reversed_logic', models.BooleanField(default=False, help_text='If set all members WITHOUT a secret santa application will pass the test.')),
                ('year', models.ForeignKey(help_text='What year to filter on.', on_delete=django.db.models.deletion.CASCADE, to='secretsanta.year')),
            ],
            options={
                'verbose_name': 'Smart Filter: Active Secret Santa',
                'verbose_name_plural': 'Smart Filter: Active Secret Santa',
                'default_permissions': (),
            },
        ),
    ]
